import { select, json, tsv, geoPath, 
        geoNaturalEarth1, zoom, event} from 'd3';
import {feature} from 'topojson';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

g.append('path')
		.attr('class', 'sphere')
		.attr('d', pathGenerator({type: 'Sphere'}));



svg.call(zoom().on('zoom', () => {
		g.attr('transform', event.transform);
		}));

Promise.all([
	tsv('https://unpkg.com/world-atlas@1/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {
  		const rowById = tsvData.reduce((accumulator, d) => {
      		accumulator[d.iso_n3] = d
        	return accumulator
      }, {});
  	
      const countries = feature(topoJSONdata, topoJSONdata.objects.countries);
      
  		countries.features.forEach( d => {
      	Object.assign(d.properties, rowById[d.id]);
      });
  
  		g.selectAll('path')
          .data(countries.features)
          .enter().append('path')
            .attr('class', 'country')
            .attr('d', pathGenerator)
  					.attr('fill', '#93ff93')
          .append('title')
            .text( d => d.properties.name)
});


	









